Class: Aws::EKSAuth::Types::AssumeRoleForPodIdentityRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eksauth/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:token]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_nameString

The name of the cluster for the request.

Returns:

  • (String)


58
59
60
61
62
63
64
65
66
# File 'lib/aws-sdk-eksauth/types.rb', line 58

class AssumeRoleForPodIdentityRequest < Struct.new(
  :cluster_name,
  :token,
  :eks_node_name,
  :instance_id,
  :zone)
  SENSITIVE = [:token]
  include Aws::Structure
end

#eks_node_nameString

The Kubernetes node name of the worker node where the pod is running.

Returns:

  • (String)


58
59
60
61
62
63
64
65
66
# File 'lib/aws-sdk-eksauth/types.rb', line 58

class AssumeRoleForPodIdentityRequest < Struct.new(
  :cluster_name,
  :token,
  :eks_node_name,
  :instance_id,
  :zone)
  SENSITIVE = [:token]
  include Aws::Structure
end

#instance_idString

The Amazon EC2 instance ID of the worker node where the pod is running.

Returns:

  • (String)


58
59
60
61
62
63
64
65
66
# File 'lib/aws-sdk-eksauth/types.rb', line 58

class AssumeRoleForPodIdentityRequest < Struct.new(
  :cluster_name,
  :token,
  :eks_node_name,
  :instance_id,
  :zone)
  SENSITIVE = [:token]
  include Aws::Structure
end

#tokenString

The token of the Kubernetes service account for the pod.

Returns:

  • (String)


58
59
60
61
62
63
64
65
66
# File 'lib/aws-sdk-eksauth/types.rb', line 58

class AssumeRoleForPodIdentityRequest < Struct.new(
  :cluster_name,
  :token,
  :eks_node_name,
  :instance_id,
  :zone)
  SENSITIVE = [:token]
  include Aws::Structure
end

#zoneString

The Availability Zone ID of the worker node where the pod is running.

Returns:

  • (String)


58
59
60
61
62
63
64
65
66
# File 'lib/aws-sdk-eksauth/types.rb', line 58

class AssumeRoleForPodIdentityRequest < Struct.new(
  :cluster_name,
  :token,
  :eks_node_name,
  :instance_id,
  :zone)
  SENSITIVE = [:token]
  include Aws::Structure
end