Class: Aws::EKSAuth::Types::AssumedRoleUser
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKSAuth::Types::AssumedRoleUser
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eksauth/types.rb
Overview
An object with the permanent IAM role identity and the temporary session name.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the IAM role that the temporary credentials authenticate to.
-
#assume_role_id ⇒ String
The session name of the temporary session requested to STS.
Instance Attribute Details
#arn ⇒ String
The ARN of the IAM role that the temporary credentials authenticate to.
134 135 136 137 138 139 |
# File 'lib/aws-sdk-eksauth/types.rb', line 134 class AssumedRoleUser < Struct.new( :arn, :assume_role_id) SENSITIVE = [] include Aws::Structure end |
#assume_role_id ⇒ String
The session name of the temporary session requested to STS. The
value is a unique identifier that contains the role ID, a colon
(:), and the role session name of the role that is being assumed.
The role ID is generated by IAM when the role is created. The role
session name part of the value follows this format:
eks-clustername-podname-random UUID
134 135 136 137 138 139 |
# File 'lib/aws-sdk-eksauth/types.rb', line 134 class AssumedRoleUser < Struct.new( :arn, :assume_role_id) SENSITIVE = [] include Aws::Structure end |