Class: Aws::EKSAuth::Types::PodIdentityAssociation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-eksauth/types.rb

Overview

Amazon EKS Pod Identity associations provide the ability to manage credentials for your applications, similar to the way that Amazon EC2 instance profiles provide credentials to Amazon EC2 instances.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_arnString

The Amazon Resource Name (ARN) of the EKS Pod Identity association.

Returns:

  • (String)


257
258
259
260
261
262
# File 'lib/aws-sdk-eksauth/types.rb', line 257

class PodIdentityAssociation < Struct.new(
  :association_arn,
  :association_id)
  SENSITIVE = []
  include Aws::Structure
end

#association_idString

The ID of the association.

Returns:

  • (String)


257
258
259
260
261
262
# File 'lib/aws-sdk-eksauth/types.rb', line 257

class PodIdentityAssociation < Struct.new(
  :association_arn,
  :association_id)
  SENSITIVE = []
  include Aws::Structure
end