Class: Aws::EKSAuth::Types::Subject
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKSAuth::Types::Subject
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eksauth/types.rb
Overview
An object containing the name of the Kubernetes service account inside the cluster to associate the IAM credentials with.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#namespace ⇒ String
The name of the Kubernetes namespace inside the cluster to create the association in.
-
#service_account ⇒ String
The name of the Kubernetes service account inside the cluster to associate the IAM credentials with.
Instance Attribute Details
#namespace ⇒ String
The name of the Kubernetes namespace inside the cluster to create the association in. The service account and the pods that use the service account must be in this namespace.
306 307 308 309 310 311 |
# File 'lib/aws-sdk-eksauth/types.rb', line 306 class Subject < Struct.new( :namespace, :service_account) SENSITIVE = [] include Aws::Structure end |