Class: Aws::EKSAuth::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::EKSAuth::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-eksauth/client.rb
Overview
An API client for EKSAuth. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::EKSAuth::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#assume_role_for_pod_identity(params = {}) ⇒ Types::AssumeRoleForPodIdentityResponse
The Amazon EKS Auth API and the ‘AssumeRoleForPodIdentity` action are only used by the EKS Pod Identity Agent.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
467 468 469 |
# File 'lib/aws-sdk-eksauth/client.rb', line 467 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
556 557 558 |
# File 'lib/aws-sdk-eksauth/client.rb', line 556 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
559 560 561 |
# File 'lib/aws-sdk-eksauth/client.rb', line 559 def errors_module Errors end |
Instance Method Details
#assume_role_for_pod_identity(params = {}) ⇒ Types::AssumeRoleForPodIdentityResponse
The Amazon EKS Auth API and the ‘AssumeRoleForPodIdentity` action are only used by the EKS Pod Identity Agent.
We recommend that applications use the Amazon Web Services SDKs to connect to Amazon Web Services services; if credentials from an EKS Pod Identity association are available in the pod, the latest versions of the SDKs use them automatically.
520 521 522 523 |
# File 'lib/aws-sdk-eksauth/client.rb', line 520 def assume_role_for_pod_identity(params = {}, = {}) req = build_request(:assume_role_for_pod_identity, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 |
# File 'lib/aws-sdk-eksauth/client.rb', line 529 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::EKSAuth') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-eksauth' context[:gem_version] = '1.19.0' Seahorse::Client::Request.new(handlers, context) end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
549 550 551 |
# File 'lib/aws-sdk-eksauth/client.rb', line 549 def waiter_names [] end |