Class: Aws::EKSAuth::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::EKSAuth::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-eksauth/client.rb
Overview
An API client for EKSAuth. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::EKSAuth::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#assume_role_for_pod_identity(params = {}) ⇒ Types::AssumeRoleForPodIdentityResponse
The Amazon EKS Auth API and the ‘AssumeRoleForPodIdentity` action are only used by the EKS Pod Identity Agent.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
422 423 424 |
# File 'lib/aws-sdk-eksauth/client.rb', line 422 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
506 507 508 |
# File 'lib/aws-sdk-eksauth/client.rb', line 506 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
509 510 511 |
# File 'lib/aws-sdk-eksauth/client.rb', line 509 def errors_module Errors end |
Instance Method Details
#assume_role_for_pod_identity(params = {}) ⇒ Types::AssumeRoleForPodIdentityResponse
The Amazon EKS Auth API and the ‘AssumeRoleForPodIdentity` action are only used by the EKS Pod Identity Agent.
We recommend that applications use the Amazon Web Services SDKs to connect to Amazon Web Services services; if credentials from an EKS Pod Identity association are available in the pod, the latest versions of the SDKs use them automatically.
475 476 477 478 |
# File 'lib/aws-sdk-eksauth/client.rb', line 475 def assume_role_for_pod_identity(params = {}, = {}) req = build_request(:assume_role_for_pod_identity, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
484 485 486 487 488 489 490 491 492 493 494 495 |
# File 'lib/aws-sdk-eksauth/client.rb', line 484 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-eksauth' context[:gem_version] = '1.8.0' Seahorse::Client::Request.new(handlers, context) end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
499 500 501 |
# File 'lib/aws-sdk-eksauth/client.rb', line 499 def waiter_names [] end |