Class: Aws::EKSAuth::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::EKSAuth::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-eksauth/client.rb
Overview
An API client for EKSAuth. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::EKSAuth::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#assume_role_for_pod_identity(params = {}) ⇒ Types::AssumeRoleForPodIdentityResponse
The Amazon EKS Auth API and the ‘AssumeRoleForPodIdentity` action are only used by the EKS Pod Identity Agent.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
385 386 387 |
# File 'lib/aws-sdk-eksauth/client.rb', line 385 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
469 470 471 |
# File 'lib/aws-sdk-eksauth/client.rb', line 469 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
472 473 474 |
# File 'lib/aws-sdk-eksauth/client.rb', line 472 def errors_module Errors end |
Instance Method Details
#assume_role_for_pod_identity(params = {}) ⇒ Types::AssumeRoleForPodIdentityResponse
The Amazon EKS Auth API and the ‘AssumeRoleForPodIdentity` action are only used by the EKS Pod Identity Agent.
We recommend that applications use the Amazon Web Services SDKs to connect to Amazon Web Services services; if credentials from an EKS Pod Identity association are available in the pod, the latest versions of the SDKs use them automatically.
438 439 440 441 |
# File 'lib/aws-sdk-eksauth/client.rb', line 438 def assume_role_for_pod_identity(params = {}, = {}) req = build_request(:assume_role_for_pod_identity, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
447 448 449 450 451 452 453 454 455 456 457 458 |
# File 'lib/aws-sdk-eksauth/client.rb', line 447 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-eksauth' context[:gem_version] = '1.2.0' Seahorse::Client::Request.new(handlers, context) end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
462 463 464 |
# File 'lib/aws-sdk-eksauth/client.rb', line 462 def waiter_names [] end |