Class: Aws::EKSAuth::Types::AssumeRoleForPodIdentityRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKSAuth::Types::AssumeRoleForPodIdentityRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eksauth/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:token]
Instance Attribute Summary collapse
-
#cluster_name ⇒ String
The name of the cluster for the request.
-
#eks_node_name ⇒ String
The Kubernetes node name of the worker node where the pod is running.
-
#instance_id ⇒ String
The Amazon EC2 instance ID of the worker node where the pod is running.
-
#token ⇒ String
The token of the Kubernetes service account for the pod.
-
#zone ⇒ String
The Availability Zone ID of the worker node where the pod is running.
Instance Attribute Details
#cluster_name ⇒ String
The name of the cluster for the request.
58 59 60 61 62 63 64 65 66 |
# File 'lib/aws-sdk-eksauth/types.rb', line 58 class AssumeRoleForPodIdentityRequest < Struct.new( :cluster_name, :token, :eks_node_name, :instance_id, :zone) SENSITIVE = [:token] include Aws::Structure end |
#eks_node_name ⇒ String
The Kubernetes node name of the worker node where the pod is running.
58 59 60 61 62 63 64 65 66 |
# File 'lib/aws-sdk-eksauth/types.rb', line 58 class AssumeRoleForPodIdentityRequest < Struct.new( :cluster_name, :token, :eks_node_name, :instance_id, :zone) SENSITIVE = [:token] include Aws::Structure end |
#instance_id ⇒ String
The Amazon EC2 instance ID of the worker node where the pod is running.
58 59 60 61 62 63 64 65 66 |
# File 'lib/aws-sdk-eksauth/types.rb', line 58 class AssumeRoleForPodIdentityRequest < Struct.new( :cluster_name, :token, :eks_node_name, :instance_id, :zone) SENSITIVE = [:token] include Aws::Structure end |
#token ⇒ String
The token of the Kubernetes service account for the pod.
58 59 60 61 62 63 64 65 66 |
# File 'lib/aws-sdk-eksauth/types.rb', line 58 class AssumeRoleForPodIdentityRequest < Struct.new( :cluster_name, :token, :eks_node_name, :instance_id, :zone) SENSITIVE = [:token] include Aws::Structure end |
#zone ⇒ String
The Availability Zone ID of the worker node where the pod is running.
58 59 60 61 62 63 64 65 66 |
# File 'lib/aws-sdk-eksauth/types.rb', line 58 class AssumeRoleForPodIdentityRequest < Struct.new( :cluster_name, :token, :eks_node_name, :instance_id, :zone) SENSITIVE = [:token] include Aws::Structure end |