Class: Aws::EKSAuth::Types::PodIdentityAssociation
- Inherits:
-
Struct
- Object
- Struct
- Aws::EKSAuth::Types::PodIdentityAssociation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-eksauth/types.rb
Overview
Amazon EKS Pod Identity associations provide the ability to manage credentials for your applications, similar to the way that Amazon EC2 instance profiles provide credentials to Amazon EC2 instances.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#association_arn ⇒ String
The Amazon Resource Name (ARN) of the EKS Pod Identity association.
-
#association_id ⇒ String
The ID of the association.
Instance Attribute Details
#association_arn ⇒ String
The Amazon Resource Name (ARN) of the EKS Pod Identity association.
257 258 259 260 261 262 |
# File 'lib/aws-sdk-eksauth/types.rb', line 257 class PodIdentityAssociation < Struct.new( :association_arn, :association_id) SENSITIVE = [] include Aws::Structure end |
#association_id ⇒ String
The ID of the association.
257 258 259 260 261 262 |
# File 'lib/aws-sdk-eksauth/types.rb', line 257 class PodIdentityAssociation < Struct.new( :association_arn, :association_id) SENSITIVE = [] include Aws::Structure end |